@@ -5,7 +5,7 @@ import requests
 from os import path
 
 
-def force_json_parameter_type(funct):
+def json_force_parameter_type(funct):
     def decorated(*args, **kwargs):
         from inspect import signature
         from json_cpp.json_object import JsonObject
